Datasets
=========

This module provides dataset implementations for concept-based learning.

Summary
-------

**Bayesian Network Datasets**

.. currentmodule:: torch_concepts.data.datasets.bnlearn
.. autosummary::
   :toctree: generated
   :nosignatures:

   BnLearnDataset

**Toy Datasets**

.. currentmodule:: torch_concepts.data.datasets.toy
.. autosummary::
   :toctree: generated
   :nosignatures:

   ToyDataset
   CompletenessDataset

**MNIST Variants**

.. currentmodule:: torch_concepts.data.datasets.mnist
.. autosummary::
   :toctree: generated
   :nosignatures:

   ColorMNISTDataset
   MNISTAddition
   PartialMNISTAddition
   MNISTEvenOdd

**Image Datasets**

.. currentmodule:: torch_concepts.data.datasets
.. autosummary::
   :toctree: generated
   :nosignatures:

   celeba.CelebADataset
   cub.CUBDataset
   awa2.AwA2Dataset

**Other Datasets**

.. autosummary::
   :toctree: generated
   :nosignatures:

   cebab.CEBaBDataset
   traffic.TrafficLights


Class Documentation
-------------------

Bayesian Network Datasets
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.datasets.bnlearn.BnLearnDataset
   :members:
   :undoc-members:
   :show-inheritance:

Toy Datasets
~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.datasets.toy.ToyDataset
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.toy.CompletenessDataset
   :members:
   :undoc-members:
   :show-inheritance:

MNIST Variants
~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.datasets.mnist.ColorMNISTDataset
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.mnist.MNISTAddition
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.mnist.PartialMNISTAddition
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.mnist.MNISTEvenOdd
   :members:
   :undoc-members:
   :show-inheritance:

Image Datasets
~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.datasets.celeba.CelebADataset
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.cub.CUBDataset
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.awa2.AwA2Dataset
   :members:
   :undoc-members:
   :show-inheritance:

Other Datasets
~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.datasets.cebab.CEBaBDataset
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: torch_concepts.data.datasets.traffic.TrafficLights
   :members:
   :undoc-members:
   :show-inheritance:
